import glob
import os

import pandas as pd
import plotly.graph_objects as go
from plotly.subplots import make_subplots

#"off":"dicht", 'on':"open"
all_files = glob.glob(os.path.join("input", "*.csv"))
li = []
for filename in all_files:
    df = pd.read_csv(filename, index_col=None, header=0)
    li.append(df)

df = pd.concat(li, axis=0, ignore_index=True)
df.drop_duplicates(inplace=True)

df['datetime'] = pd.to_datetime(df['datetime'])
df=df.sort_values(by='datetime').reset_index(drop=True)


def get_by_metadata(metadata_id):
    response = df[df['metadata_id'] == metadata_id].drop(columns='metadata_id')
    return response.set_index(response['datetime'])['state']


co2 = get_by_metadata(2269).astype(int)
first_date = co2.index[0]
last_date = co2.index[-1]


def extendIndex(item):  #extend data
    if item.index[-1] < last_date:
        item.at[last_date] = item[item.index[-1]]
    if item.index[0] > first_date:
        item.at[first_date] = item[item.index[0]]

booleans = {
    'Raam open': 420,
    'Ventilator aan': 2295,
}

#Co2 krijgt de helft van de ruimte, de rest is voor de booleans.
rijhoogtes=[0.5]
rijhoogtes.extend([0.5/len(booleans)]*len(booleans))
fig = make_subplots(rows=len(booleans) + 1, cols=1, shared_xaxes=True, row_heights=rijhoogtes)


#Co2
co2_trace = go.Scatter(x=co2.index, y=co2.values, mode='lines', name="Co2")
fig.add_trace(co2_trace, row=1, col=1)
fig.update_yaxes(title_text='Co2', row=1, rangemode='tozero', fixedrange=True)

#Boolean-variabelen
for index, key in enumerate(booleans):
    item = get_by_metadata(booleans[key]).replace({"off": False, 'on': True})
    extendIndex(item)
    trace = go.Scatter(x=item.index, y=item.values.astype(float), mode='lines', name=key, line_shape='hv')
    fig.add_trace(trace, row=index + 2, col=1)
    fig.update_yaxes(row=index+2, title_text=key, fixedrange=True,
                     tickvals=[0,1], ticktext=["nee", "ja"], showgrid=False)
    fig.update_xaxes(row=index+2, range=[first_date, last_date], rangeslider=dict(visible=False))

fig.update_layout(autosize=True, showlegend=False, margin=dict(l=50, r=50, t=50, b=50),)

fig.write_html("output/all.html", include_plotlyjs='cdn')